@@ -15,19 +15,21 @@
 """
 
 try:
-    from PySide6.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QApplication, QWidget, QFileDialog, QMessageBox, QSizePolicy, QGridLayout, QCheckBox, QFrame, QLineEdit, QPushButton
+    from PySide6.QtWidgets import QTabWidget, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QWidget, QGridLayout, QCheckBox, QFrame, QLineEdit, QRadioButton
+
     from PySide6.QtCore import Qt, QTranslator, QCoreApplication, QLocale
-    from PySide6 import QtCore, QtGui, QtWidgets
+    from PySide6 import QtCore
     from PySide6.QtGui import QIcon
 except:
-    from PyQt5.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QApplication, QWidget, QFileDialog, QMessageBox, QSizePolicy, QGridLayout, QCheckBox, QFrame, QLineEdit, QPushButton
+    from PyQt5.QtWidgets import QTabWidget, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QWidget, QGridLayout, QCheckBox, QFrame, QLineEdit, QRadioButton
     from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
-    from PyQt5 import QtCore, QtGui, QtWidgets
+    from PyQt5 import QtCore
     from PyQt5.QtGui import QIcon
 
 from persepolis.gui import resources
 from persepolis.gui.customized_widgets import MyQDateTimeEdit
 
+
 class AddLinkWindow_Ui(QWidget):
     def __init__(self, persepolis_setting):
         super().__init__()
@@ -181,8 +183,20 @@ class AddLinkWindow_Ui(QWidget):
 
         proxy_verticalLayout.addWidget(self.proxy_frame)
 
-        proxy_verticalLayout.addStretch(1)
+        # type of proxy
+        self.http_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.http_radioButton, 4, 0, 1, 1)
 
+        self.https_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.https_radioButton, 5, 0, 1, 1)
+
+        # hide this widget until https support
+        self.https_radioButton.hide()
+
+        self.socks5_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.socks5_radioButton, 6, 0, 1, 1)
+
+        proxy_verticalLayout.addStretch(1)
         self.add_link_tabWidget.addTab(self.proxy_tab, '')
 
         # more options tab
@@ -285,24 +299,12 @@ class AddLinkWindow_Ui(QWidget):
         # limit Speed ->
         limit_verticalLayout = QVBoxLayout()
 
-        self.limit_checkBox = QCheckBox(self.more_options_tab)
-        limit_verticalLayout.addWidget(self.limit_checkBox)
-
         self.limit_frame = QFrame(self.more_options_tab)
         self.limit_frame.setFrameShape(QFrame.StyledPanel)
         self.limit_frame.setFrameShadow(QFrame.Raised)
 
-        horizontalLayout_4 = QHBoxLayout(self.limit_frame)
+        verticalLayout_4 = QVBoxLayout(self.limit_frame)
 
-        self.limit_spinBox = QDoubleSpinBox(self.limit_frame)
-        self.limit_spinBox.setMinimum(1)
-        self.limit_spinBox.setMaximum(1023)
-        horizontalLayout_4.addWidget(self.limit_spinBox)
-
-        self.limit_comboBox = QComboBox(self.limit_frame)
-        self.limit_comboBox.addItem("")
-        self.limit_comboBox.addItem("")
-        horizontalLayout_4.addWidget(self.limit_comboBox)
         limit_verticalLayout.addWidget(self.limit_frame)
         time_limit_horizontalLayout.addLayout(limit_verticalLayout)
         more_options_tab_verticalLayout.addLayout(time_limit_horizontalLayout)
@@ -315,15 +317,14 @@ class AddLinkWindow_Ui(QWidget):
         self.connections_frame.setFrameShape(QFrame.StyledPanel)
         self.connections_frame.setFrameShadow(QFrame.Raised)
 
-        horizontalLayout_3 = QHBoxLayout(self.connections_frame)
         self.connections_label = QLabel(self.connections_frame)
-        horizontalLayout_3.addWidget(self.connections_label)
+        verticalLayout_4.addWidget(self.connections_label)
 
         self.connections_spinBox = QSpinBox(self.connections_frame)
         self.connections_spinBox.setMinimum(1)
-        self.connections_spinBox.setMaximum(16)
-        self.connections_spinBox.setProperty("value", 16)
-        horizontalLayout_3.addWidget(self.connections_spinBox)
+        self.connections_spinBox.setMaximum(64)
+        self.connections_spinBox.setProperty("value", 64)
+        verticalLayout_4.addWidget(self.connections_spinBox)
         connections_horizontalLayout.addWidget(self.connections_frame)
         connections_horizontalLayout.addStretch(1)
 
@@ -423,6 +424,10 @@ class AddLinkWindow_Ui(QWidget):
         self.proxy_user_label.setText(QCoreApplication.translate("addlink_ui_tr", "Proxy username: "))
         self.port_label.setText(QCoreApplication.translate("addlink_ui_tr", "Port:"))
 
+        self.http_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "HTTP"))
+        self.https_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "HTTPS"))
+        self.socks5_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "SOCKS5"))
+
         self.download_checkBox.setText(QCoreApplication.translate("addlink_ui_tr", "Download username and password"))
         self.download_user_label.setText(QCoreApplication.translate("addlink_ui_tr", "Download username: "))
         self.download_pass_label.setText(QCoreApplication.translate("addlink_ui_tr", "Download password: "))
@@ -434,10 +439,6 @@ class AddLinkWindow_Ui(QWidget):
         self.start_checkBox.setText(QCoreApplication.translate("addlink_ui_tr", "Start time"))
         self.end_checkBox.setText(QCoreApplication.translate("addlink_ui_tr", "End time"))
 
-        self.limit_checkBox.setText(QCoreApplication.translate("addlink_ui_tr", "Limit speed"))
-        self.limit_comboBox.setItemText(0, "KiB/s")
-        self.limit_comboBox.setItemText(1, "MiB/s")
-
         self.connections_label.setText(QCoreApplication.translate("addlink_ui_tr", "Number of connections:"))
 
         self.cancel_pushButton.setText(QCoreApplication.translate("addlink_ui_tr", "Cancel"))
