@@ -63,32 +63,28 @@ class PropertiesWindow(AddLinkWindow_Ui):
 
         self.callback = callback
 
-# detect_proxy_pushButton
+        # detect_proxy_pushButton
         self.detect_proxy_pushButton.clicked.connect(
             self.detectProxy)
 
-# connect folder_pushButton
+        # connect folder_pushButton
         self.folder_pushButton.clicked.connect(self.changeFolder)
         self.download_folder_lineEdit.setEnabled(False)
 
         self.ok_pushButton.setEnabled(False)
         self.link_lineEdit.textChanged.connect(self.linkLineChanged)
 
-# connect OK and cancel button
-
+        # connect OK and cancel button
         self.cancel_pushButton.clicked.connect(self.close)
         self.ok_pushButton.clicked.connect(self.okButtonPressed)
 
-#frames and checkBoxes
+        # frames and checkBoxes
         self.proxy_frame.setEnabled(False)
         self.proxy_checkBox.toggled.connect(self.proxyFrame)
 
         self.download_frame.setEnabled(False)
         self.download_checkBox.toggled.connect(self.downloadFrame)
 
-        self.limit_frame.setEnabled(False)
-        self.limit_checkBox.toggled.connect(self.limitFrame)
-
         self.start_frame.setEnabled(False)
         self.start_checkBox.toggled.connect(self.startFrame)
 
@@ -113,9 +109,8 @@ class PropertiesWindow(AddLinkWindow_Ui):
             for key in self.add_link_dictionary_2.keys():
                 self.add_link_dictionary_2_backup[key] = self.add_link_dictionary_2[key]
 
-
-# initialization
-# disable folder_frame when download is complete
+        # initialization
+        # disable folder_frame when download is complete
         if self.video_finder_dictionary:
             if self.video_finder_dictionary['video_completed'] == 'yes' or self.video_finder_dictionary['audio_completed'] == 'yes':
                 self.folder_frame.setEnabled(False)
@@ -123,64 +118,76 @@ class PropertiesWindow(AddLinkWindow_Ui):
             if self.download_table_dict_1['status'] == 'complete':
                 self.folder_frame.setEnabled(False)
 
-
-# link
+        # link
         self.link_lineEdit.setText(self.add_link_dictionary_1['link'])
 
         if self.video_finder_dictionary:
             self.link_lineEdit_2.setText(self.add_link_dictionary_2['link'])
 
-# ip_lineEdit initialization
+        # ip_lineEdit initialization
         if self.add_link_dictionary_1['ip']:
             self.proxy_checkBox.setChecked(True)
             self.ip_lineEdit.setText(self.add_link_dictionary_1['ip'])
-# port_spinBox initialization
+            # port_spinBox initialization
             try:
                 self.port_spinBox.setValue(
                     int(self.add_link_dictionary_1['port']))
             except:
                 pass
-# proxy user lineEdit initialization
+            # proxy user lineEdit initialization
             try:
                 self.proxy_user_lineEdit.setText(
                     self.add_link_dictionary_1['proxy_user'])
             except:
                 pass
-# proxy pass lineEdit initialization
+            # proxy pass lineEdit initialization
             try:
                 self.proxy_pass_lineEdit.setText(
                     self.add_link_dictionary_1['proxy_passwd'])
             except:
                 pass
 
+        # proxy type
+        proxy_type = self.add_link_dictionary_1['proxy_type']
 
-# download UserName initialization
+        # default is http
+        if proxy_type == 'socks5':
+
+            self.socks5_radioButton.setChecked(True)
+
+        elif proxy_type == 'https':
+            self.https_radioButton.setChecked(True)
+
+        else:
+            self.http_radioButton.setChecked(True)
+
+        # download UserName initialization
         if self.add_link_dictionary_1['download_user']:
             self.download_checkBox.setChecked(True)
             self.download_user_lineEdit.setText(
                 self.add_link_dictionary_1['download_user'])
-# download PassWord initialization
+            # download PassWord initialization
             try:
                 self.download_pass_lineEdit.setText(
                     self.add_link_dictionary_1['download_passwd'])
             except:
                 pass
 
-# folder_path
+        # folder_path
         try:
             self.download_folder_lineEdit.setText(
                 self.add_link_dictionary_1['download_path'])
         except:
             pass
 
-# connections
+        # connections
         try:
             self.connections_spinBox.setValue(
                 int(self.add_link_dictionary_1['connections']))
         except:
             pass
 
-# get categories name and add them to add_queue_comboBox
+        # get categories name and add them to add_queue_comboBox
         categories_list = self.parent.persepolis_db.categoriesList()
         for queue in categories_list:
             if queue != 'All Downloads':
@@ -193,24 +200,10 @@ class PropertiesWindow(AddLinkWindow_Ui):
             self.current_category)
         self.add_queue_comboBox.setCurrentIndex(current_category_index)
 
-
-# add_queue_comboBox event
+        # add_queue_comboBox event
         self.add_queue_comboBox.currentIndexChanged.connect(self.queueChanged)
 
-
-# limit speed
-        limit = str(self.add_link_dictionary_1['limit_value'])
-        if limit != '0':
-            self.limit_checkBox.setChecked(True)
-            limit_number = limit[0:-1]
-            limit_unit = limit[-1]
-            self.limit_spinBox.setValue(float(limit_number))
-            if limit_unit == "K":
-                self.limit_comboBox.setCurrentIndex(0)
-            else:
-                self.limit_comboBox.setCurrentIndex(1)
-
-# start_time
+        # start_time
         if self.add_link_dictionary_1['start_time']:
             # get hour and minute
             hour, minute = self.add_link_dictionary_1['start_time'].split(':')
@@ -220,7 +213,7 @@ class PropertiesWindow(AddLinkWindow_Ui):
             self.start_time_qDataTimeEdit.setTime(q_time)
 
             self.start_checkBox.setChecked(True)
-# end_time
+        # end_time
         if self.add_link_dictionary_1['end_time']:
             # get hour and minute
             hour, minute = self.add_link_dictionary_1['end_time'].split(':')
@@ -244,8 +237,7 @@ class PropertiesWindow(AddLinkWindow_Ui):
         if self.add_link_dictionary_1['load_cookies']:
             self.load_cookies_lineEdit.setText((self.add_link_dictionary_1['load_cookies']))
 
-
-# set window size and position
+        # set window size and position
         size = self.persepolis_setting.value(
             'PropertiesWindow/size', QSize(520, 425))
         position = self.persepolis_setting.value(
@@ -253,7 +245,7 @@ class PropertiesWindow(AddLinkWindow_Ui):
         self.resize(size)
         self.move(position)
 
-# detect system proxy setting, and set ip_lineEdit and port_spinBox
+    # detect system proxy setting, and set ip_lineEdit and port_spinBox
     def detectProxy(self, button):
         # get system proxy information
         system_proxy_dict = getProxy()
@@ -278,8 +270,8 @@ class PropertiesWindow(AddLinkWindow_Ui):
             self.proxy_checkBox.setChecked(False)
             self.detect_proxy_label.setText('No proxy detected!')
 
+    # activate frames if checkBoxes checked
 
-# activate frames if checkBoxes checked
     def proxyFrame(self, checkBox):
 
         if self.proxy_checkBox.isChecked():
@@ -294,13 +286,6 @@ class PropertiesWindow(AddLinkWindow_Ui):
         else:
             self.download_frame.setEnabled(False)
 
-    def limitFrame(self, checkBox):
-
-        if self.limit_checkBox.isChecked():
-            self.limit_frame.setEnabled(True)
-        else:
-            self.limit_frame.setEnabled(False)
-
     def startFrame(self, checkBox):
 
         if self.start_checkBox.isChecked():
@@ -346,63 +331,63 @@ class PropertiesWindow(AddLinkWindow_Ui):
             self.start_checkBox.setEnabled(True)
             self.end_checkBox.setEnabled(True)
 
-    def okButtonPressed(self, button):
-        # write user's new inputs in persepolis_setting for next time if needed
-        if self.folder_checkBox.isChecked() == True:
-            self.persepolis_setting.setValue(
-                'settings/download_path', self.download_folder_lineEdit.text())
+    # this method returns proxy information.
+    def getProxyInformation(self):
+        # http, https or socks5 proxy
+        if self.http_radioButton.isChecked() is True:
 
-        if not(self.proxy_checkBox.isChecked()):
+            proxy_type = 'http'
+
+        elif self.https_radioButton.isChecked() is True:
+
+            proxy_type = 'https'
+
+        else:
+
+            proxy_type = 'socks5'
+
+        # get proxy information
+        if not (self.proxy_checkBox.isChecked()):
             ip = None
             port = None
             proxy_user = None
             proxy_passwd = None
+            proxy_type = None
         else:
             ip = self.ip_lineEdit.text()
-            if not(ip):
+            if not (ip):
                 ip = None
-            port = str(self.port_spinBox.value())
-            if not(port):
+
+            port = self.port_spinBox.value()
+            if not (port):
                 port = None
+
             proxy_user = self.proxy_user_lineEdit.text()
-            if not(proxy_user):
+            if not (proxy_user):
                 proxy_user = None
+
             proxy_passwd = self.proxy_pass_lineEdit.text()
-            if not(proxy_passwd):
+            if not (proxy_passwd):
                 proxy_passwd = None
 
-        if not(self.download_checkBox.isChecked()):
+        return ip, port, proxy_user, proxy_passwd, proxy_type
+
+    def getUserPass(self):
+        # get download username and password information
+        if not (self.download_checkBox.isChecked()):
             download_user = None
             download_passwd = None
         else:
             download_user = self.download_user_lineEdit.text()
-            if not(download_user):
+            if not (download_user):
                 download_user = None
             download_passwd = self.download_pass_lineEdit.text()
-            if not(download_passwd):
+            if not (download_passwd):
                 download_passwd = None
 
-        if not(self.limit_checkBox.isChecked()):
-            limit = 0
-        else:
-            if self.limit_comboBox.currentText() == "KiB/s":
-                limit = str(self.limit_spinBox.value()) + str("K")
-            else:
-                limit = str(self.limit_spinBox.value()) + str("M")
-
-        if not(self.start_checkBox.isChecked()):
-            start_time = None
-        else:
-            start_time = self.start_time_qDataTimeEdit.text()
-
-        if not(self.end_checkBox.isChecked()):
-            end_time = None
-        else:
-            end_time = self.end_time_qDateTimeEdit.text()
-
-        connections = self.connections_spinBox.value()
-        download_path = self.download_folder_lineEdit.text()
+        return download_user, download_passwd
 
+    def getAdditionalInformation(self):
         # referer
         if self.referer_lineEdit.text() != '':
             referer = self.referer_lineEdit.text()
@@ -427,6 +412,38 @@ class PropertiesWindow(AddLinkWindow_Ui):
         else:
             load_cookies = None
 
+        return referer, header, user_agent, load_cookies
+
+    def okButtonPressed(self, button):
+        # write user's new inputs in persepolis_setting for next time if needed
+        if self.folder_checkBox.isChecked() is True:
+            self.persepolis_setting.setValue(
+                'settings/download_path', self.download_folder_lineEdit.text())
+
+        # get proxy information
+        ip, port, proxy_user, proxy_passwd, proxy_type = self.getProxyInformation()
+        if proxy_type is not None:
+            self.persepolis_setting.setValue('add_link_initialization/proxy_type', proxy_type)
+
+        # get download username and password information
+        download_user, download_passwd = self.getUserPass()
+
+        if not (self.start_checkBox.isChecked()):
+            start_time = None
+        else:
+            start_time = self.start_time_qDataTimeEdit.text()
+
+        if not (self.end_checkBox.isChecked()):
+            end_time = None
+        else:
+            end_time = self.end_time_qDateTimeEdit.text()
+
+        connections = self.connections_spinBox.value()
+        download_path = self.download_folder_lineEdit.text()
+
+        # get additinal information
+        referer, header, user_agent, load_cookies = self.getAdditionalInformation()
+
         self.add_link_dictionary_1['start_time'] = start_time
         self.add_link_dictionary_1['end_time'] = end_time
         self.add_link_dictionary_1['link'] = self.link_lineEdit.text()
@@ -434,10 +451,10 @@ class PropertiesWindow(AddLinkWindow_Ui):
         self.add_link_dictionary_1['port'] = port
         self.add_link_dictionary_1['proxy_user'] = proxy_user
         self.add_link_dictionary_1['proxy_passwd'] = proxy_passwd
+        self.add_link_dictionary_1['proxy_type'] = proxy_type
         self.add_link_dictionary_1['download_user'] = download_user
         self.add_link_dictionary_1['download_passwd'] = download_passwd
         self.add_link_dictionary_1['download_path'] = download_path
-        self.add_link_dictionary_1['limit_value'] = limit
         self.add_link_dictionary_1['connections'] = connections
         self.add_link_dictionary_1['referer'] = referer
         self.add_link_dictionary_1['header'] = header
@@ -452,10 +469,10 @@ class PropertiesWindow(AddLinkWindow_Ui):
             self.add_link_dictionary_2['port'] = port
             self.add_link_dictionary_2['proxy_user'] = proxy_user
             self.add_link_dictionary_2['proxy_passwd'] = proxy_passwd
+            self.add_link_dictionary_2['proxy_type'] = proxy_type
             self.add_link_dictionary_2['download_user'] = download_user
             self.add_link_dictionary_2['download_passwd'] = download_passwd
             self.add_link_dictionary_2['download_path'] = download_path
-            self.add_link_dictionary_2['limit_value'] = limit
             self.add_link_dictionary_2['connections'] = connections
             self.add_link_dictionary_2['referer'] = referer
             self.add_link_dictionary_2['header'] = header
@@ -471,12 +488,39 @@ class PropertiesWindow(AddLinkWindow_Ui):
             # update data base
             self.parent.persepolis_db.updateDownloadTable([self.download_table_dict_1])
 
+            # update category_db_table
+            # remove download item from old category
+            old_category_dict = self.parent.persepolis_db.searchCategoryInCategoryTable(self.current_category)
+            old_category_gid_list = old_category_dict['gid_list']
+            old_category_gid_list.remove(self.gid_1)
+            self.parent.persepolis_db.updateCategoryTable([old_category_dict])
+
+            # add download item to new category
+            new_category_dict = self.parent.persepolis_db.searchCategoryInCategoryTable(new_category)
+            new_category_gid_list = new_category_dict['gid_list']
+            new_category_gid_list.append(self.gid_1)
+            self.parent.persepolis_db.updateCategoryTable([new_category_dict])
+
             if self.video_finder_dictionary:
 
                 # category for audio and video must be same as each other
                 self.download_table_dict_2['category'] = new_category
                 self.parent.persepolis_db.updateDownloadTable([self.download_table_dict_2])
 
+                # update category_db_table
+                # remove download item from old category
+                old_category_dict = self.parent.persepolis_db.searchCategoryInCategoryTable(self.current_category)
+                old_category_gid_list = old_category_dict['gid_list']
+                old_category_gid_list.remove(self.gid_2)
+                self.parent.persepolis_db.updateCategoryTable([old_category_dict])
+
+                # add download item to new category
+                new_category_dict = self.parent.persepolis_db.searchCategoryInCategoryTable(new_category)
+                new_category_gid_list = new_category_dict['gid_list']
+                new_category_gid_list.append(self.gid_2)
+                self.parent.persepolis_db.updateCategoryTable([new_category_dict])
+
+
         # if any thing in add_link_dictionary_1 is changed,then update data base!
         for key in self.add_link_dictionary_1.keys():
             if self.add_link_dictionary_1[key] != self.add_link_dictionary_1_backup[key]:
@@ -489,7 +533,7 @@ class PropertiesWindow(AddLinkWindow_Ui):
 
         # if link changed, then update download_db_table in data base
         if self.add_link_dictionary_1['link'] != self.add_link_dictionary_1_backup['link']:
-            
+
             dictionary = {'gid': self.gid_1, 'link': self.add_link_dictionary_1['link']}
             self.parent.persepolis_db.updateDownloadTable([dictionary])
 
@@ -506,7 +550,7 @@ class PropertiesWindow(AddLinkWindow_Ui):
 
             # if link changed, then update download_db_table in data base
             if self.add_link_dictionary_2['link'] != self.add_link_dictionary_2_backup['link']:
-                
+
                 dictionary = {'gid': self.gid_2, 'link': self.add_link_dictionary_2['link']}
                 self.parent.persepolis_db.updateDownloadTable([dictionary])
 
@@ -527,7 +571,6 @@ class PropertiesWindow(AddLinkWindow_Ui):
         if event.key() == Qt.Key_Escape:
             self.close()
 
-
     def closeEvent(self, event):
         # save window size and position
         self.persepolis_setting.setValue('PropertiesWindow/size', self.size())
